@@ -73,7 +73,10 @@ class S3:
 
 	def rm(self, path, recursive=True, **kwargs):
 		path = self._get_absolute_path(path)
-		return self.file_system.delete(path=path, recursive=recursive, **kwargs)
+		result = self.file_system.delete(path=path, recursive=recursive, **kwargs)
+		if self.exists(path):
+			raise FileExistsError(f'path "{path}" was not deleted!')
+		return result
 
 	def mkdir(self, path, **kwargs):
 		path = self._get_absolute_path(path)
